#!/user/bin/python

import sys
from scipy.io import wavfile
from scipy import signal
import noisereduce as nr
import numpy as np
import time

t1 = time.perf_counter(), time.process_time()

# load data
rate, data = wavfile.read(sys.argv[1])
print(f'sample rate:{rate} maximum: {max(data)} type: {type(data[0])}')

t2 = time.perf_counter(), time.process_time()
print(f"Load real time: {t2[0] - t1[0]:.2f} s CPU time: {t2[1] - t1[1]:.2f} s")

# perform noise reduction
reduced_noise = nr.reduce_noise(y=data, sr=rate)

t2 = time.perf_counter(), time.process_time()
print(f"Noise real time: {t2[0] - t1[0]:.2f} s CPU time: {t2[1] - t1[1]:.2f} s")

# design and apply highpass filter
cutoff = 2000.0
b, a = signal.butter(N=6, Wn=cutoff, btype='highpass', fs=rate)
filtered = signal.filtfilt(b, a, reduced_noise)

t2 = time.perf_counter(), time.process_time()
print(f"Filter real time: {t2[0] - t1[0]:.2f} s CPU time: {t2[1] - t1[1]:.2f} s")

normalization = int(32000 / max(filtered))
#normalization = 1

print(f'maximum: {max(filtered)} type: {type(filtered[0])}')

output = (filtered * normalization).astype(np.int16)

t2 = time.perf_counter(), time.process_time()
print(f"Normalize real time: {t2[0] - t1[0]:.2f} s CPU time: {t2[1] - t1[1]:.2f} s")

#print(f'maximum: {max(output)} type: {type(output[0])}')
print("Completed noise reduction")

wavfile.write(sys.argv[2], rate, output)
t2 = time.perf_counter(), time.process_time()
print(f"Output real time: {t2[0] - t1[0]:.2f} s CPU time: {t2[1] - t1[1]:.2f} s")

